function [names, values] = nd_imgedgefeatures(imageproc)
% MB_IMGFEATURES - calculates features for IMAGEPROC
% [NAMES, VALUES, SLFNAMES] = MB_IMGFEATURES(IMAGEPROC),
%    where IMAGEPROC contains the pre-processed fluorescence image.
%    Pre-processed means that the image has been cropped and had
%    pixels of interest selected (via a threshold, for instance).
%   Features calculated include:
%   (The following feature descriptions were added here by T. Zhao 
%   according to the reference 
%   "R. F. Murphy, M. Velliste, and G. Porreca (2003) Robust Numerical 
%   Features for Description and Classification of Subcellular Location 
%   Patterns in Fluorescence Microscope Images. J. VLSI Sig. Proc. 35: 
%   311-321.")
%   1. Fraction of above-threshold pixels along edge
%   2. Measure of edge gradient intensity homogenerity
%   3. Measure of edge direction homogenerity 1
%   4. Measure of edge direction homogenerity 2
%   5. Measure of edge direction difference

% Total area of the image that is edges
A = bwarea(edge(imageproc,'canny',[]))/bwarea(im2bw(imageproc));

% Directional edge filters
N = [1 1 1 ; 0 0 0 ; -1 -1 -1];
W = [1 0 -1 ; 1 0 -1 ; 1 0 -1];

% Calculation of the gradient from two orthogonal directions
iprocN = filter2(N,imageproc);
iprocW = filter2(W,imageproc);

% Calculate the magnitude and direction of the gradient
iprocmag = sqrt(iprocN.^2 + iprocW.^2);
iproctheta = atan2(iprocN, iprocW);
iproctheta(iproctheta==-pi)=pi;
nonzero = find(iprocmag);
v = iproctheta(nonzero);
v_mag = iprocmag(nonzero);

% Histogram the gradient directions
h = hist(v,8);

% max/min ratio
[hmax maxidx] = max(h);
hmin = min(h);
if (hmin ~= 0),
  maxminratio = hmax/hmin;
else
  maxminratio = 0;
end
htmp=h;
htmp(maxidx) = 0;
hnextmax = max(htmp);
maxnextmaxratio=hmax/hnextmax;

% Difference between bins of histogram at angle and angle+pi
diff = abs(h(1:4)-h(5:8))./abs(h(1:4)+h(5:8));
diff(abs(h(1:4)-h(5:8))==0) = 0;
sumdiff=sum(diff);

% Measure of edge homogeneity - what fraction of edge pixels are in
%  the first two bins of the histogram.
h_mag = hist(v_mag,4);
homogeneity = sum(h_mag(1))/sum(h_mag(:));

names = {'edges:area_fraction' 'edges:homogeneity' 'edges:direction_maxmin_ratio'...
    'edges:direction_maxnextmax_ratio' 'edges:direction_difference'};
values = [A homogeneity maxminratio maxnextmaxratio sumdiff];


