function [names, values] = nd_imgfeatures(imageproc)

% [NAMES, VALUES] = ML_IMGFEATURES(IMAGEPROC)
%
%    Calculates features for IMAGEPROC
%    where IMAGEPROC contains the pre-processed fluorescence image, 
%    and DNAPROC the pre-processed DNA fluorescence image.
%    Pre-processed means that the image has been cropped and had 
%    pixels of interest selected (via a threshold, for instance).
%
%    Features calculated include:
%      - Number of objects
%      - Euler number of the image (# of objects - # of holes)
%      - Average of the object sizes
%      - Variance of the object sizes
%      - Ratio of the largest object to the smallest
%      - Average of the object distances from the COF
%      - Variance of the object distances from the COF
%      - Ratio of the largest object distance to the smallest

% Features from imfeature()
features = regionprops(double(im2bw(imageproc)),'EulerNumber');

% Calculate the number of objects in IMAGE
imagelabeled = bwlabel(im2bw(imageproc));
obj_number = max(imagelabeled(:));

% Calculate the center of fluorescence of IMAGE
imageproc_m00 = ml_imgmoments(imageproc,0,0);
imageproc_m01 = ml_imgmoments(imageproc,0,1);
imageproc_m10 = ml_imgmoments(imageproc,1,0);
imageproc_center = [imageproc_m10/imageproc_m00; imageproc_m01/imageproc_m00];

% Find the maximum and minimum object sizes, and the distance 
%    of each object to the center of fluorescence

[img_moment00, img_moment10, img_moment01, obj_size] = ml_moments_1(int32(imageproc),int32(imagelabeled));

obj_size = obj_size(1,2:obj_number+1);
obj_minsize = max(obj_size);
obj_maxsize = min(obj_size);
obj_size_avg = mean(obj_size);
obj_size_var = var(obj_size) ;
obj_size_ratio = obj_maxsize/obj_minsize;

img_moment00 = img_moment00(1,2:obj_number+1);
img_moment10 = img_moment10(1,2:obj_number+1);
img_moment01 = img_moment01(1,2:obj_number+1);

obj_center = [img_moment10./img_moment00; img_moment01./img_moment00];
obj_distance = sqrt((obj_center(1,:) - imageproc_center(1)).^2 + (obj_center(2,:) - imageproc_center(2)).^2)';

obj_dist_avg = mean(obj_distance);
obj_dist_var = var(obj_distance);

obj_maxdist = max(obj_distance);
obj_mindist = min(obj_distance);

if obj_mindist ~= 0 
	obj_dist_ratio = obj_maxdist/obj_mindist ;
else
	obj_dist_ratio = 0 ;
end
                                            
names = {'object:number' 'object:EulerNumber' 'object_size:average' 'object_size:variance' 'object_size:ratio'...
    'object_distance:average' 'object_distance:variance' 'object_distance:ratio'};
values = [obj_number features.EulerNumber obj_size_avg obj_size_var obj_size_ratio obj_dist_avg obj_dist_var obj_dist_ratio];


